﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Esri.ArcGISRuntime.Controls;
using Esri.ArcGISRuntime.LocalServices;
using Esri.ArcGISRuntime.Layers;
using Esri.ArcGISRuntime.Geometry;

namespace TestRotation
{
  /// <summary>
  /// Interaction logic for MainWindow.xaml
  /// </summary>
  public partial class MainWindow : Window
  {
    int rotationAngle = 0;

    public MainWindow()
    {
      InitializeComponent();
      rotAngle.Text = rotationAngle.ToString();

      setup();
    }

    private void Button_Click(object sender, RoutedEventArgs e)
    {
      if (((Button)sender).Content.ToString() == "Up")
      {
        rotationAngle++;
        if (rotationAngle == 360)
        {
          rotationAngle = 0;
        }
      }
      else
      {
        rotationAngle--;
        if (rotationAngle == -1)
        {
          rotationAngle = 359;
        }
      }

      rotAngle.Text = rotationAngle.ToString();
      esriMap.SetRotation(rotationAngle);
    }

    private void esriMap_ExtentChanged(object sender, EventArgs e)
    {
      MapScaleText.Text = string.Format("Map Scale: 1:{0:#,##.#}", esriMap.Scale);
    }

    private void esriMap_MouseMove(object sender, MouseEventArgs e)
    {
      MapPoint mpt = esriMap.ScreenToLocation(e.GetPosition(esriMap));
      if (mpt != null)
      {
        XYText.Text = string.Format(" X:{0:#,##.#} Y:{1:#,##.#}", mpt.X, mpt.Y);
      }
    }

    /// <summary>
    /// 
    /// </summary>
    private async void setup()
    {
      this.Width = 520;
      this.Height = 600;
      await CreateLocalServiceAndDynamicLayer();
      MapPoint mpt = new MapPoint(7644139, 681151);
//      esriMap.PanTo(mpt);
      await esriMap.ZoomToScaleAsync(7500);
    }
    /// <summary>
    /// 
    /// </summary>
    /// <returns></returns>
    public async Task CreateLocalServiceAndDynamicLayer()
    {
      LocalMapService localMapService = new LocalMapService(@"..\..\portland-rotate.mpk");

      try
      {
        await localMapService.StartAsync();

        ArcGISDynamicMapServiceLayer arcGISDynamicMapServiceLayer = new ArcGISDynamicMapServiceLayer()
        {
          ID = "arcGISDynamicMapServiceLayer",
          ServiceUri = localMapService.UrlMapService,
        };

        esriMap.Map.Layers.Add(arcGISDynamicMapServiceLayer);
      }
      catch (Exception ex)
      {
        MessageBox.Show(ex.Message);
      }
    }

  }
}
